==> checker-3.4.0.jar: annotated-jdk/src/java.base/share/classes/java/lang/Number.java <==
/*
 * Copyright (c) 1994, 2015, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package java.lang;

import org.checkerframework.checker.lock.qual.GuardSatisfied;
import org.checkerframework.dataflow.qual.Pure;
import org.checkerframework.framework.qual.AnnotatedFor;

@AnnotatedFor({ "lock", "nullness" })
public abstract class Number implements java.io.Serializable {

    @Pure
    public abstract int intValue(@GuardSatisfied Number this);

    @Pure
    public abstract long longValue(@GuardSatisfied Number this);

    @Pure
    public abstract float floatValue(@GuardSatisfied Number this);

    @Pure
    public abstract double doubleValue(@GuardSatisfied Number this);

    @Pure
    public byte byteValue(@GuardSatisfied Number this);

    @Pure
    public short shortValue(@GuardSatisfied Number this);
}

==> checker-3.28.0.jar: annotated-jdk/src/java.base/share/classes/java/lang/Number.java <==
/*
 * Copyright (c) 1994, 2021, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package java.lang;

import org.checkerframework.checker.lock.qual.GuardSatisfied;
import org.checkerframework.common.value.qual.PolyValue;
import org.checkerframework.dataflow.qual.Pure;
import org.checkerframework.framework.qual.AnnotatedFor;

@AnnotatedFor({ "lock", "nullness", "value" })
public abstract class Number implements java.io.Serializable {

    public Number() {
    }

    @Pure
    @PolyValue
    public abstract int intValue(@GuardSatisfied @PolyValue Number this);

    @Pure
    @PolyValue
    public abstract long longValue(@GuardSatisfied @PolyValue Number this);

    @Pure
    @PolyValue
    public abstract float floatValue(@GuardSatisfied @PolyValue Number this);

    @Pure
    @PolyValue
    public abstract double doubleValue(@GuardSatisfied @PolyValue Number this);

    @Pure
    @PolyValue
    public byte byteValue(@GuardSatisfied @PolyValue Number this);

    @Pure
    @PolyValue
    public short shortValue(@GuardSatisfied @PolyValue Number this);
}
